

set -ex



test -f $PREFIX/include/nlopt.h
test -f $PREFIX/include/nlopt.hpp
test -f $PREFIX/lib/pkgconfig/nlopt.pc
test -f $PREFIX/lib/libnlopt.so.0
test -f $PREFIX/lib/libnlopt.so.0.11.1
test -f $PREFIX/lib/libnlopt.so
exit 0
